@import "colors";

.btn-trust {
  position: relative;
  cursor: pointer;
  margin: 5px;
  padding: 5px 20px;
  border-width: 0;
  outline: none;
  border-radius: 5px;
  box-shadow: 0 1px 4px rgba(0, 0, 0, .6);
  background-color: $primary;
  color: $blanco;
  transition: background-color .3s;
  &:hover, &:focus {
    background-color: $primary-dark;
    color: $blanco;
  }
  &:before {
    content: "";
    position: absolute;
    top: 50%;
    left: 50%;
    display: block;
    width: 0;
    padding-top: 0;
    border-radius: 100%;
    background-color: rgba(236, 240, 241, .3);
    -webkit-transform: translate(-50%, -50%);
    -moz-transform: translate(-50%, -50%);
    -ms-transform: translate(-50%, -50%);
    -o-transform: translate(-50%, -50%);
    transform: translate(-50%, -50%);
  }
  &:active:before {
    width: 120%;
    padding-top: 120%;
    transition: width .2s ease-out, padding-top .2s ease-out;
  }
  &-sm {
    font-size: .7em;
  }
  &-md {
    font-size: 1em;
  }
  &-lg {
    font-size: 1.3em;
  }

}